@@ -6,6 +6,8 @@
 
 import urllib3
 
+from distutils.version import StrictVersion as version
+
 from bases.FrameworkServices.SimpleService import SimpleService
 
 try:
@@ -14,9 +16,30 @@ except AttributeError:
     pass
 
 
+# https://github.com/urllib3/urllib3/blob/master/CHANGES.rst#19-2014-07-04
+# New retry logic and urllib3.util.retry.Retry configuration object. (Issue https://github.com/urllib3/urllib3/pull/326)
+URLLIB3_MIN_REQUIRED_VERSION = '1.9'
+URLLIB3_VERSION = urllib3.__version__
+URLLIB3 = 'urllib3'
+
+
+def version_check():
+    if version(URLLIB3_VERSION) >= version(URLLIB3_MIN_REQUIRED_VERSION):
+        return
+
+    err = '{0} version: {1}, minimum required version: {2}, please upgrade'.format(
+        URLLIB3,
+        URLLIB3_VERSION,
+        URLLIB3_MIN_REQUIRED_VERSION,
+    )
+    raise Exception(err)
+
+
 class UrlService(SimpleService):
     def __init__(self, configuration=None, name=None):
+        version_check()
         SimpleService.__init__(self, configuration=configuration, name=name)
+        self.debug("{0} version: {1}".format(URLLIB3, URLLIB3_VERSION))
         self.url = self.configuration.get('url')
         self.user = self.configuration.get('user')
         self.password = self.configuration.get('pass')
